/* 
   Author: Mark A. Hassman (mark@lost.strange.com)
   Version: 1.0
   Copyright:  GNU General Public License
*/

#include "copyright.h"

#include "fde.h"
#include <string.h>

#define CYBERWEAR_DB  "data/cyberwear.dat"
#define CYBERLIMBS_DB "data/cyberlimbs.dat"
#define CYBERAUDIO_DB "data/cyberaudio.dat"
#define CYBEROPTIC_DB "data/cyberoptic.dat"

#define AUDIO	1
#define OPTIC	2
#define LIMBS	3

extern float decrypt_diestr(char *);

/* gen_cyberwear_opts:  Generate specific options correlated to
   a type of cyberwear.
 */

void FDE::gen_cyberwear(void)
{
   char buff[181], *ptr, *cost, *hloss;
   int rolls=0, cnt=0, which=0, i=0, line_num=0;
   FILE *f;

   // init our array to something silly, do the same with the main one
   strcpy(buff,"foobargleep");
   strcpy(cybernetics,"");
   HL = 0.0;

   // determine how many rolls we are going to make.
   if(role == SOLO)
	rolls = die(4) + 3 + die( (age-16) / 6 );
   else
	rolls = die(3) + 1 + die( (age-16) / 6 );


  f=fopen(CYBERWEAR_DB,"r");
  if(!f)  // File failed to open.  Blab about it.
  {
     cgiHeaderContentType("text/html");
     fprintf(cgiOut,"<html><head></head><body>\n");
     fprintf(cgiOut,"<h2>Weapon file failed to open!</h2>");
     fprintf(cgiOut,"</body></html>\n");
  }

  // Data file is open, lets generate a count of possible 
  // gear to generate.

  while(f && buff[0] != '\n')
  {
    fgets(buff, 180, f);
    cnt++;
  }
  // Count is one less than returned;
  cnt--;

  // Failsafe:   If we don't have any options to generate, 
  // return nothing.
  if(cnt == 0)
  {
    strcpy(cybernetics,"None");
    return;
  }

  for(i=0; i < rolls; i++)
  {
    // Reposition file pointer to top of db file.
    fseek(f, 0, SEEK_SET);
    // Determine which line we want...
    which = die(cnt);
    // Go get that line.
    line_num=0;
    while(line_num != which)
    {
      fgets(buff, 180, f);
      line_num++;
    }

    // Okay, we should have a cyberwear object in the buffer.
    // Check to make sure a copy isn't already in the cybernetics
    // list for the fde and then copy it in.
    //  Advanced options for limbs, optics and audio will come
    //  Later.

    // Chop off everything but the name.  HL will be handled later
   
    //ptr=strchr(buff,'|');
    //*ptr='\0';
    ptr = strtok(buff, "|");
    cost = strtok(NULL, "|");
    hloss = strtok(NULL, "|");
    if(hloss)
      HL += decrypt_diestr(hloss);

    ptr=strstr(cybernetics, buff);
    if(!ptr)  // Cool, its not already in there.
    {
       if(i == 0)  // first one, just copy it.
          strcpy(cybernetics, buff);
       else
       {
          strcat(cybernetics, ", ");
	  strcat(cybernetics, buff);
       }
       // Add on special cases for audio, optics & limbs.
       ptr=strstr(buff,"Cyberaudio");
       if(ptr)
	  gen_cyberwear_opts(AUDIO,die(3));
       ptr=strstr(buff,"Front Optic Mount");
       if(ptr && (die(2)-1))
	  gen_cyberwear_opts(OPTIC,die(3));
       else if(ptr)
	  gen_cyberwear_opts(AUDIO,die(3));

       ptr=strstr(buff,"Cyberoptic");
       if(ptr)
	  gen_cyberwear_opts(OPTIC,die(3));
       ptr=strstr(buff,"Cyberleg");
       if(ptr)
	  gen_cyberwear_opts(LIMBS,die(2));
       ptr=strstr(buff,"Cyberarm");
       if(ptr)
	  gen_cyberwear_opts(LIMBS,die(2));
      

    }
    else
      i--;  // Duplicate, reduce count by one and continue.
  }
}

void FDE::gen_cyberwear_opts(int opt_type, int rolls)
{
  FILE *f;
  char buff[181], *ptr, *cost, *hloss;
  int i=0, cnt=0, which=0, line_num=0;

  switch(opt_type)
  {
	case AUDIO:
	   f=fopen(CYBERAUDIO_DB,"r");
	   break;
	case OPTIC:
	   f=fopen(CYBEROPTIC_DB,"r");
	   break;
	case LIMBS:
	   f=fopen(CYBERLIMBS_DB,"r");
	   break;
	default:
	   f=fopen("/home/data/punk/error_log", "a");
	   fprintf(f,"ERROR/CYBEROPTS: Invalid opt_type passed to gen_cyberwear_opts in cyberwear.cpp\n");
	   fclose(f);
	   return;
  }


  // In case of file failure in above, blurb an error
  if(!f)
  {
    f=fopen("/home/data/punk/error_log", "a");
    fprintf(f,"ERROR/CYBEROPTS: File opening failure on Type %d\n",
	opt_type);
    fclose(f);
  }

  // Okay, generate total option count for this file.
  while(f && buff[0] != '\n')
  {
    fgets(buff, 181, f);
    cnt++;
  }
  cnt--;

  if(cnt == 0)
  {
    fclose(f);
    f=fopen("/home/data/punk/error_log", "a");
    fprintf(f,"ERROR/CYBEROPTS: Empty file failure on Type %d\n",
	opt_type);
    fclose(f);
    return;
  }
 
  strcat(cybernetics," (<i>");
  for(i=0; i < rolls; i++)
  {
    fseek(f,0,SEEK_SET);
    which = die(cnt);
    line_num = 0;
    while(line_num != which)
    {
      fgets(buff, 180, f);
      line_num++;
    }  
    // Hack off costs & hl nums
    ptr=strtok(buff, "|");
    cost=strtok(NULL,"|");
    hloss=strtok(NULL,"|");
    if(hloss)
       HL += decrypt_diestr(hloss);

    ptr=strstr(cybernetics,buff);
    if(!ptr)
    {
      if(i != 0)
        strcat(cybernetics, ", ");
      strcat(cybernetics,buff);
    }
    else
      i--;
  }
  strcat(cybernetics,"</i>)");

}
