/*
   Author: Mark A. Hassman  (mark@lost.strange.com)
   Version: 1.0
   Copyright:  GNU General Public License
*/
#include "copyright.h"


/* Weapon generation */
#include "gma.h"
#include "weapon.h"
#include <string.h>

WEAPON::WEAPON()
{

  WA = Shots = ROF = Cost = 0;
  strcpy(Name,"");
  strcpy(Type,"");
  strcpy(Dmg,"");
  strcpy(Rel,"");
  strcpy(Range,"");
  Con = Avail = ' ';
}

void WEAPON::gen_weapon(int ID)
{
  FILE *f;
  int line_cnt=0, which=0;
  char *ptr;
  char buf[161];

  strcpy(buf,"");


// Open the proper file based on the incoming definition 
  switch(ID)
  {
	case PISTOL:
		f=fopen(PISTOL_DB,"r");
	  	break;
	case SMG:
		f=fopen(SMG_DB,"r");
		break;
	case RIFLE:
		f=fopen(RIFLE_DB,"r");
		break;
 	case SHOTGUN:
		f=fopen(SHOTGUN_DB,"r");
		break;
	case HEAVY:
		f=fopen(HEAVY_DB,"r");
		break;
	case EXOTIC:
		f=fopen(EXOTIC_DB,"r");
		break;
	case MELEE:
		f=fopen(MELEE_DB,"r");
		break;
	default:
		f=fopen(ERROR_LOG,"a");
		fprintf(f,"WEAPON/gen_weapon: Default case matched on type %d. No results returned.\n", ID);
		fclose(f);
		return;
		break;
  }

// If we don't have a file, we need to report it and exit, 
// the default case can be outputed but it will look odd.
if(!f)
{
	f=fopen(ERROR_LOG,"a");
	fprintf(f,"WEAPON/gen_weapon: Data file failed to open on Class %d\n",
		ID);
	fclose(f);
	return;
}

// We have a good file, its already open, let's generate the count
// of weapons for this specific file.
  while(f && buf[0] != '\n')
  {
    fgets(buf,160,f);
    line_cnt++;
  }
  line_cnt--;
// Reposition the file pointer to the head of the file, 0 offset.
  fseek(f, 0, SEEK_SET);

// Select the line to get.

  which = die(line_cnt);

// Read through the file to that line.

  line_cnt=0;


  while(line_cnt != which)
  {
    fgets(buf,160,f);
    line_cnt++;
  }

// We should now have the weapon in the bufer.
// Close the file, convert the bufer into useful data.

  fclose(f);


// If a strtok fails, we have a fatal bug. :P

  // Weapon Name
  ptr=strtok(buf,"|");  // We do this second as strtok destroys buf
  if(ptr)
    strcpy(Name, ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  // Weapon Type
  ptr=strtok(NULL,"|");
  if(ptr)
    strcpy(Type,ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    WA = atoi(ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    Con = *ptr;
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    Avail = *ptr;
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    strcpy(Dmg,ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    Shots = atoi(ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    ROF = atoi(ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    strcpy(Rel,ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    strcpy(Range,ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

  ptr=strtok(NULL,"|");
  if(ptr)
    Cost=atoi(ptr);
  else
  {
    sprintf(Name,"Weapon Generation Failure. ID=%d, Line=%d", ID, which);
    return;
  }

// We should have a good weapon for the most part, we're done.
  return;
}


void WEAPON::display_weapon_html(void)
{
  // We have more data elements that we will need but they were
  // included just in case of need for future releases.

  fprintf(cgiOut,"<tr><td align=center bgcolor=#cccccc colspan=9>");
  fprintf(cgiOut,"<b>Weapon</b></td></tr>\n");
  fprintf(cgiOut,"<tr>");
  fprintf(cgiOut,"<td align=center colspan=2>Name</td>");
  fprintf(cgiOut,"<td align=center>Type</td>");
  fprintf(cgiOut,"<td align=center>WA</td>");
  fprintf(cgiOut,"<td align=center>Con</td>");
  fprintf(cgiOut,"<td align=center>Dmg</td>");
  fprintf(cgiOut,"<td align=center>Shots</td>");
  fprintf(cgiOut,"<td align=center>ROF</td>");
//  fprintf(cgiOut,"<td align=center>Rel</td>");
  fprintf(cgiOut,"<td align=center>Range</td>");
  fprintf(cgiOut,"</tr>\n");
  fprintf(cgiOut,"<tr>");
  fprintf(cgiOut,"<td colspan=2>%s</td>", Name);
  fprintf(cgiOut,"<td align=center>%s</td>", Type);
  fprintf(cgiOut,"<td align=center>%d</td>", WA);
  fprintf(cgiOut,"<td align=center>%c</td>", Con);
  fprintf(cgiOut,"<td align=center>%s</td>", Dmg);
  fprintf(cgiOut,"<td align=center>%d</td>", Shots);
  fprintf(cgiOut,"<td align=center>%d</td>", ROF);
//  fprintf(cgiOut,"<td align=center>%s</td>", Rel);
  fprintf(cgiOut,"<td align=center>%s</td>", Range);
  fprintf(cgiOut,"</tr>\n");
  return;
}


